pari_seadata_big: PARI data package needed by ellap for large primes (big version)
==================================================================================

Description
-----------

Needed by ellap for large primes. These polynomials were extracted from
the ECHIDNA databases and computed by David R. Kohel.
This contains extra modular polynomials of level between 500 and 800.
This is suitable for fields up to 1100 bits.
PARI/GP 2.9 contains fallback
code to go on when all modular polynomials in the database have been
exhausted and can handle larger fields (with an important slowdown).

License
-------

GNU General Public License (GPL version 2 or any later version).


Upstream Contact
----------------

http://pari.math.u-bordeaux.fr/
